@@ -46,7 +46,7 @@ from elastic_blast.cost import BQ_ERROR, NO_RESULTS_ERROR, CMD_ARGS_ERROR
 from elastic_blast.util import SafeExecError, UserReportError
 from elastic_blast.aws import handle_aws_error
 import elastic_blast.gcp
-from elastic_blast.elb_config import generate_cluster_name
+from elastic_blast.elb_config import generate_cluster_name, CloudURI
 
 DFLT_GCP_PROJECT='nihsgcnlmncbi'
 
@@ -173,7 +173,7 @@ def aws_cost_by_cluster(args):
     if args.aws_cluster_name:
         cluster_name = args.aws_cluster_name
     else:
-        cluster_name = generate_cluster_name(args.aws_results)
+        cluster_name = generate_cluster_name(CloudURI(args.aws_results))
     if args.date_range:
         start_time, end_time = args.date_range.split(':')
     else:
