@@ -42,6 +42,7 @@ trap "/bin/rm -fr $src $dst $inclusions $exclusions " INT QUIT EXIT HUP KILL ALR
 # These paths (except .git) will be deleted from final output
 cat >$exclusions<<EOF
 .git
+.teamcity
 share
 demo
 setenv.sh
@@ -72,7 +73,6 @@ share/etc/elastic-blast-aws-iam-policy.json.template
 share/etc/yamllint-config.yaml
 share/etc/elb-aws-blastn-nt-8-nodes.ini
 share/etc/elb-blastp-nr.ini
-share/tools/cleanup-stale-gcp-resources.py
 EOF
 rsync -Cvac --files-from=$inclusions $src/ $dst/
 
